OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "북마크",
    "No file provided for import" : "가져올 파일을 지정하지 않았음",
    "Unsupported file type for import" : "지원하지 않는 가져오기 파일 형식",
    "Bookmarks shared by %s" : "%s이(가) 공유한 북마크 ",
    "A Bookmark manager for Nextcloud" : "Nextcloud 북마크 관리자",
    "Select bookmark" : "북마크 선택",
    "Details" : "자세한 정보",
    "Rename" : "이름 바꾸기",
    "Move" : "이동",
    "Delete" : "삭제",
    "Select all" : "Select all",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
    "_Selected %n folder_::_Selected %n folders_" : ["선택된 %n 폴더들"],
    "New" : "새로 만들기",
    "New bookmark" : "새로운 북마크",
    "New folder" : "새 폴더",
    "Enter a link" : "링크를 입력하시오.",
    "Add a bookmark" : "북마크 추가",
    "Select folder" : "폴더 선택",
    "Enter folder title" : "폴더명을 입력하시오.",
    "Shared by {user}" : "{user}가 공유한",
    "Submit" : "제출",
    "Cancel" : "취소",
    "Recent" : "최근 항목",
    "Untagged" : "태그 지우기",
    "Import" : "가져오기",
    "Export" : "내보내기",
    "Bookmarklet" : "북마크릿",
    "Add to {instanceName}" : "{instanceName}에 더하기",
    "Title" : "직위",
    "Link" : "링크",
    "Tags" : "태그",
    "Notes" : "Notes",
    "Owner" : "Owner",
    "Sharing" : "공유",
    "Share link" : "링크 공유",
    "Copy link" : "링크 복사",
    "Delete link" : "링크 삭제",
    "Allow editing" : "Allow editing",
    "Link copied" : "링크 복사됨",
    "Privacy" : "프라이버시",
    "Previews" : "미리 보기",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API 키",
    "Failed to save settings" : "환경설정 저장 실패",
    "Failed to load settings" : "환경설정 로딩 실패",
    "This URL is already bookmarked! Overwrite?" : "이 URL이 북마크에 이미 추가되어 있습니다! 덮어쓰시겠습니까?",
    "Enter bookmark title" : "북마크 제목을 입력하시오.",
    "Enter bookmark URL" : "북마크 URL을 입력하시오.",
    "Folder" : "폴더",
    "Root Folder" : "최상위 폴더",
    "Save" : "저장",
    "Bookmarks feed" : "북마크 피드"
},
"nplurals=1; plural=0;");
